# Generated by roxygen2: do not edit by hand

S3method(coef,base_learner)
S3method(coef,poisson_superlearner)
S3method(predict,base_learner)
S3method(predict,poisson_superlearner)
S3method(predictRisk,base_learner)
S3method(predictRisk,poisson_superlearner)
S3method(print,base_learner)
S3method(print,poisson_superlearner)
S3method(summary,base_learner)
S3method(summary,poisson_superlearner)
export(Learner_gam)
export(Learner_glmnet)
export(Learner_hal)
export(Superlearner)
export(fit_learner)
export(pch_absolute_risk)
export(pch_absolute_risk_euler)
export(pch_survival)
export(predictRisk.poisson_superlearner)
export(simulateStenoT1)
exportClasses(Learner_gam)
exportClasses(Learner_glmnet)
exportClasses(Learner_hal)
import(data.table)
import(sampling)
importFrom(Matrix,sparse.model.matrix)
importFrom(Rcpp,evalCpp)
importFrom(glmnet,cv.glmnet)
importFrom(glmnet,glmnet)
importFrom(methods,new)
importFrom(mgcv,gam)
importFrom(riskRegression,predictRisk)
importFrom(stats,coef)
importFrom(stats,deviance)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,relevel)
importFrom(stats,time)
importFrom(utils,head)
importFrom(utils,tail)
useDynLib(poissonsuperlearner, .registration = TRUE)
