utils::globalVariables(c(
  ".", "..columns_ss", "..z_covariates",
  "LDL_hinge3_sq", "age_hinge55_sq",
  "absolute_risk", "covariate", "deviance", "internal_psl_ix",
  "deltaij", "deltatime", "dummy",
  "event", "folder", "id", "k", "node",
  "pwc_cols", "status_cvd", "survival_function",
  "tij", "time", "time.event.0", "time.event.1", "time.event.2",
  "time_cvd", "time_cvd",
  "uncensored_event", "uncensored_status_cvd", "uncensored_time", "uncensored_time_cvd",
  "value_AlbuminuriaMacro", "value_AlbuminuriaMicro",
  "vec_dt", "vec_dt2",
  "log2_eGFR_old", "log2_eGFR_young","row_ix","competing_risk"
))
