% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print.R
\name{print.base_learner}
\alias{print.base_learner}
\title{Print method for \code{base_learner}}
\usage{
\method{print}{base_learner}(x, cause = 1, ...)
}
\arguments{
\item{x}{\code{base_learner} object returned by \code{\link[=fit_learner]{fit_learner()}}.}

\item{cause}{\code{numeric(1)} or \code{NULL}. Which cause to print the fitted model for.
If \code{NULL}, prints one line per cause (classes only) instead of printing the full
fitted objects.}

\item{...}{Passed to the underlying fitted object \code{print()} method when \code{cause}
is a single integer.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Prints a compact description of the fitted base learner, including the learner
type, the time-grid used, and (optionally) the fitted model object for a given
cause.
}
\examples{
d <- simulateStenoT1(30, competing_risks = TRUE)
lrn <- Learner_glmnet(
  covariates = c("sex", "value_LDL"),
  lambda = 0.01,
  cross_validation = FALSE
)
bl <- fit_learner(
  d,
  learner = lrn,
  id = "id",
  status = "status_cvd",
  event_time = "time_cvd",
  number_of_nodes = 3
)
print(bl, cause = NULL)


}
